from sports.nba.nba_team import NBA_Team


class UtahJazz(NBA_Team):
    """
    NBA's Washington Wizards Static Information

    """

    full_name = "Utah Jazz"
    name = "Jazz"
    team_id = 1610612762

    def __init__(self):
        """
        """
        super().__init__()


from sports.nba.nba_team import NBA_Team


class PortlandTrailBlazers(NBA_Team):
    """
    NBA's Portland TrailBlazers Static Information

    """
    full_name = "Portland TrailBlazers"
    name = "TrailBlazers"
    team_id = 1610612757

    def __init__(self):
        """
        """
        super().__init__()




from sports.nba.nba_team import NBA_Team


class HoustonRockets(NBA_Team):
    """
    NBA Golden State Warriors Static Information

    """
    full_name = "Houston Rockets"
    name = "Rockets"
    team_id = 1610612745

    def __init__(self):
        """
        """
        super().__init__()



class Game(dict):
    def __init__(self, **kw):
        dict.__init__(self, kw)
        self.__dict__.update(kw)

        # Assigned via game.xml
        self.home_team= None
        self.away_team = None
        self.stadium = None

        # Assigned via ????
        self.innings = []

        # Assigned Via game_events.xml
        self.at_bats = []




from sports.nba.nba_team import NBA_Team


class Philadelphia76ers(NBA_Team):
    """
    NBA's Philadelphia 76ers Static Information

    """
    full_name = "Philadelphia 76ers"
    name = "76ers"
    team_id = 1610612755

    def __init__(self):
        """
        """
        super().__init__()
